@@ -1,14 +1,13 @@
 # -*- coding: utf-8 -*-
 
 from django.core.urlresolvers import reverse
-from django.contrib.sites.models import Site
 
 class AccountManagerMiddleware:
     def process_response(self, request, response):
         try:
-            current_site = Site.objects.get_current()
-            url = "http://%s%s" % (current_site, reverse('amcd'))
-            response['X-Account-Management'] = url
+            url = "%s://%s%s" % (request.META['wsgi.url_scheme'], request.META['HTTP_HOST'], reverse('amcd'))
+            link = "<%s>; rel=\"acct-mgmt\"" % url
+            response['Link'] = link
             if request.user.is_authenticated():
                 response['X-Account-Management-Status'] = 'active; name="%s"' % (request.user.username)
             else:
